@@ -1,15 +1,13 @@
 package S2::FW::Command::default;
-use Mojo::Base 'Mojolicious::Command';
+use Mojo::Base 'Mojolicious::Command', -signatures;
 
 use S2::FW::Controller::Firewall;
 
 has description => 'Apply default mode unless skip reset is set';
 has usage       => "Usage: APPLICATION default\n";
 
-sub run {
-    my $self = shift;
-
-    my $c = $self->app->build_controller(S2::FW::Controller::Firewall->new);
+sub run ($self) {
+    my $c    = $self->app->build_controller(S2::FW::Controller::Firewall->new);
     my $rows = $c->query_nft;
     my @cmd;
     foreach my $row (@$rows) {
@@ -17,8 +15,8 @@ sub run {
         push @cmd, $c->prepare_nft($row, $row->{default} // 'blocked');
     }
 
-    $c->log->debug("nft " . join('; ', @cmd));
-    $c->log->info("NFTables: restoring defaults");
+    $c->log->debug('nft ' . join('; ', @cmd));
+    $c->log->info('NFTables: restoring defaults');
     exec '/usr/sbin/nft', join('; ', @cmd);
 }
 
